plot.rma.glmm <- function(x, qqplot=FALSE, ...) {

   #########################################################################

   mstyle <- .get.mstyle()

   .chkclass(class(x), must="rma.glmm", notav="rma.glmm")

}
